@@ -2,5 +2,5 @@ from django.apps import AppConfig
 
 
 class Config(AppConfig):
-    name = 'unicef_security'
+    name = "unicef_security"
     verbose_name = "UNICEF Security"
