@@ -2,6 +2,5 @@ from unicef_security.models import AbstractUser
 
 
 class User(AbstractUser):
-
     class Meta(AbstractUser.Meta):
-        app_label = 'demo'
+        app_label = "demo"
