@@ -6,14 +6,14 @@ from demo.models import User
 class UserFactory(factory.django.DjangoModelFactory):
     class Meta:
         model = User
-        django_get_or_create = ('username',)
+        django_get_or_create = ("username",)
 
     username = factory.Sequence(lambda n: "m%03d@unicef.org" % n)
 
-    last_name = factory.Faker('last_name')
-    first_name = factory.Faker('first_name')
+    last_name = factory.Faker("last_name")
+    first_name = factory.Faker("first_name")
 
     email = factory.Sequence(lambda n: "m%03d@unicef.org" % n)
-    password = 'password'
+    password = "password"
     is_superuser = False
     is_active = True
