@@ -1,11 +1,13 @@
 import vcr
 
-VCR = vcr.VCR(serializer='yaml',
-              record_mode='once',
-              match_on=['uri', 'method'],
-              filter_headers=['authorization', 'token'],
-              filter_post_data_parameters=['client_id', 'client_secret'],
-              decode_compressed_response=True)
+VCR = vcr.VCR(
+    serializer="yaml",
+    record_mode="once",
+    match_on=["uri", "method"],
+    filter_headers=["authorization", "token"],
+    filter_post_data_parameters=["client_id", "client_secret"],
+    decode_compressed_response=True,
+)
 
 
 # def _getvcr(request, env):
